       IDENTIFICATION DIVISION.
       PROGRAM-ID.    RPTCATGY.
      *
      *    THIS PROGRAM PRINTS A REPORT OF ALL ITEMS IN THE HOUSEHOLD
      *    INVENTORY FIELD IN PRIMARY KEY (CATEGORY/SEQUENCE #) ORDER.
      *    SINCE THE INDEXED FILE IS ALREADY IN ORDER, NO SORT IS
      *    NEEDED.
      *
       AUTHOR.          R ROGER COLE.
       DATE-WRITTEN.    JANUARY, 2002.
       DATE-COMPILED.
       ENVIRONMENT DIVISION.
       CONFIGURATION SECTION.
       INPUT-OUTPUT SECTION.
       FILE-CONTROL.
           SELECT MASTER-FILE          ASSIGN TO DISK
                                       FILE STATUS IS FILE-STAT
                                       ACCESS MODE IS SEQUENTIAL
                                       ORGANIZATION IS INDEXED
                                       RECORD KEY IS OURSTUFF-KEY.
           SELECT PRINT-FILE           ASSIGN TO PRINTER.
       DATA DIVISION.
       FILE SECTION.
       FD  MASTER-FILE                                                     
           LABEL RECORDS ARE STANDARD
           VALUE OF FILE-ID IS "OURSTUFF.DAT".
       COPY OURSTUFF.CPY.                                                  
                                                                          
       FD  PRINT-FILE
           LABEL RECORDS ARE OMITTED.
       01  PRINT-FILE-RECORD           PIC X(132).
       WORKING-STORAGE SECTION.

       77  FILE-STAT                   PIC  X(02).
       77  CAT-LINE-MAX                PIC  9(02).
       77  SUB-TOTAL-AMT               PIC  9(07)          VALUE ZERO.
       77  GRAND-TOTAL-AMT             PIC  9(07)          VALUE ZERO.

       COPY CATEGORY.CPY.

       01  DETAIL-LINE-1.
           05  FILLER                  PIC  X(15).
           05  DL1-KEY                 PIC  X(06).
           05  FILLER                  PIC  X(05).
           05  DL1-LOCATION            PIC  X(12).
           05  FILLER                  PIC  X(05).
           05  DL1-PURCHASE-DATE       PIC  X(08).
           05  FILLER                  PIC  X(05).
           05  DL1-PURCHASE-PRICE      PIC  ZZZ,ZZ9.
           05  FILLER                  PIC  X(05).
           05  DL1-DESCRIPTION         PIC  X(50).

       01  TOTAL-LINE.
           05  FILLER              PIC  X(40)  VALUE SPACES.
           05  TL-TOT-WD           PIC  X(15)  VALUE " ** SUBTOTAL **". 
           05  TL-AMOUNT           PIC  ZZZZ,ZZ9.

       01  HEADING-LINE-1.
           05  FILLER              PIC  X(14)  VALUE "PROGRAM NAME: ".
           05  HL1-PROGRAM         PIC  X(08)  VALUE SPACES.
           05  FILLER              PIC  X(20)  VALUE SPACES.
           05  HL1-HEAD-1          PIC  X(50)  VALUE SPACES.
           05  FILLER              PIC  X(29)  VALUE SPACES.
           05  FILLER              PIC  X(06)  VALUE "PAGE: ".
           05  HL1-PAGE-NO         PIC  ZZZZ9.

       01  HEADING-LINE-2.
           05  FILLER              PIC  X(14)  VALUE "CURRENT DATE: ".
           05  HL1-RUN-DATE        PIC  X(08)  VALUE SPACES.
           05  FILLER              PIC  X(20)  VALUE SPACES.
           05  HL1-HEAD-2          PIC  X(50)  VALUE SPACES.
           05  FILLER              PIC  X(29)  VALUE SPACES.
           05  FILLER              PIC  X(06)  VALUE "TIME: ".
           05  HL1-RUN-TIME        PIC  X(05)  VALUE SPACES.

       01  HEADING-LINE-3.
           05  FILLER              PIC  X(132) VALUE ALL "*".

       01  HEADING-WK-VARIABLES.
           05  HD-BLANK-LINE       PIC  X(01)  VALUE SPACES.
           05  HD-LINE-CNT         PIC  9(02)  VALUE 60.
           05  HD-LINE-MAX         PIC  9(02)  VALUE 60.
           05  HD-PAGE-NO          PIC  9(04)  VALUE ZERO.

       01  SUBHEADING-LINE-1.
           05  FILLER              PIC  X(44)  VALUE
               "                                           A".
           05  FILLER              PIC  X(44)  VALUE
               "CQUIRED     ACQUIRED                        ".
           05  FILLER              PIC  X(44)  VALUE
               "                                            ".

       01  SUBHEADING-LINE-2.
           05  FILLER              PIC  X(44)  VALUE
               "                KEY       LOCATION          ".
           05  FILLER              PIC  X(44)  VALUE
               " DATE         PRICE               DESCRIPTIO".
           05  FILLER              PIC  X(44)  VALUE
               "N                                           ".

       01  MISC-FIELDS.
           05  END-INPUT-FLAG              PIC  X(01)      VALUE SPACES.  
               88 NO-MORE-INPUT                            VALUE 'Y'.     
           05  MISC-DATE.
               10  MD-YY                   PIC  X(02).
               10  MD-MM                   PIC  X(02).
               10  MD-DD                   PIC  X(02).
           05  MISC-TIME.
               10  MT-HH                   PIC  X(02).
               10  MT-MM                   PIC  X(02).
               10  MT-SS                   PIC  X(02).
           05  FORMATTED-DATE.
               10  FD-MM                   PIC  X(02).
               10  FILLER                  PIC  X(01)      VALUE "/".
               10  FD-DD                   PIC  X(02).
               10  FILLER                  PIC  X(01)      VALUE "/".
               10  FD-YY                   PIC  X(02).
           05  FORMATTED-TIME.
               10  FT-HH                   PIC  X(02).
               10  FILLER                  PIC  X(01)      VALUE ":".
               10  FT-MM                   PIC  X(02).
           05  SAVE-CLASS                  PIC  X(03)      VALUE SPACES.
           05  PRT-CATEGORY-DESC           PIC  X(20)      VALUE SPACES.

       PROCEDURE DIVISION.
       A000.                                                              
                                                                          
           OPEN INPUT  MASTER-FILE.                                          
           OPEN OUTPUT PRINT-FILE.                                        

           PERFORM A100-INITIALIZE THRU A199-EXIT.
           PERFORM R100-START THRU R199-EXIT.
           PERFORM R200-READ-NEXT THRU R299-EXIT.
                                                                          
           PERFORM C100-PROCESS-RECORDS THRU C199-EXIT                    
               UNTIL NO-MORE-INPUT.                                       

           PERFORM T100-GIVE-SUB-TOTAL THRU T199-EXIT.
           PERFORM T200-GIVE-GRAND-TOTAL THRU T299-EXIT.
           CLOSE MASTER-FILE                                                
                 PRINT-FILE.
           STOP RUN.                                                      

       A100-INITIALIZE.

           MOVE  "RPTCATGY"                TO  HL1-PROGRAM.
           MOVE  "              HOME INVENTORY ITEMS" TO HL1-HEAD-1.
           MOVE  "                   BY CATEGORY    " TO HL1-HEAD-2.
           ACCEPT  MISC-DATE               FROM  DATE.
           MOVE  MD-YY                     TO  FD-YY.
           MOVE  MD-MM                     TO  FD-MM.
           MOVE  MD-DD                     TO  FD-DD.
           MOVE  FORMATTED-DATE            TO  HL1-RUN-DATE.
           ACCEPT  MISC-TIME               FROM  TIME.
           MOVE  MT-HH                     TO  FT-HH.
           MOVE  MT-MM                     TO  FT-MM.
           MOVE  FORMATTED-TIME            TO  HL1-RUN-TIME.
           MOVE  SPACES                    TO  DETAIL-LINE-1.
           COMPUTE CAT-LINE-MAX = HD-LINE-MAX - 4.

       A199-EXIT.

           EXIT.




       C100-PROCESS-RECORDS.

           IF  OURSTUFF-CLASS NOT = SAVE-CLASS
               PERFORM H200-CATEGORY-NAME THRU H299-EXIT.

           MOVE  OURSTUFF-KEY              TO  DL1-KEY.
           MOVE  OURSTUFF-LOCATION         TO  DL1-LOCATION.
           MOVE  OURSTUFF-PURCHASE-DATE    TO  MISC-DATE.
           MOVE  MD-YY                     TO  FD-MM.
           MOVE  MD-MM                     TO  FD-DD.
           MOVE  MD-DD                     TO  FD-YY.
           MOVE  FORMATTED-DATE            TO  DL1-PURCHASE-DATE.
           MOVE  OURSTUFF-PURCHASE-PRICE   TO  DL1-PURCHASE-PRICE.
           ADD   OURSTUFF-PURCHASE-PRICE   TO  SUB-TOTAL-AMT.
           MOVE  OURSTUFF-DESCRIPTION      TO  DL1-DESCRIPTION.
           MOVE  OURSTUFF-CLASS            TO  SAVE-CLASS.

           PERFORM P100-PRINT-DETAIL THRU P199-EXIT.

       C180-READ-NEXT.

           PERFORM R200-READ-NEXT THRU R299-EXIT.

       C199-EXIT.

           EXIT.                                                          
                                                                          
                                                                          

       H100-PRINT-HEADING.

           ADD  1                          TO  HD-PAGE-NO.
           MOVE  HD-PAGE-NO                TO  HL1-PAGE-NO.
           WRITE PRINT-FILE-RECORD     FROM  HEADING-LINE-1 AFTER PAGE.
           WRITE PRINT-FILE-RECORD     FROM  HEADING-LINE-2 AFTER 1.
           WRITE PRINT-FILE-RECORD     FROM  HEADING-LINE-3 AFTER 1.
           WRITE PRINT-FILE-RECORD     FROM  SUBHEADING-LINE-1 AFTER 1.
           WRITE PRINT-FILE-RECORD     FROM  SUBHEADING-LINE-2 AFTER 1.
           WRITE PRINT-FILE-RECORD     FROM  HEADING-LINE-3 AFTER 1.
           WRITE PRINT-FILE-RECORD     FROM  HD-BLANK-LINE  AFTER 1.
           MOVE  7                         TO  HD-LINE-CNT.

       H199-EXIT.

           EXIT.




       H200-CATEGORY-NAME.

           IF  HD-LINE-CNT NOT LESS THAN CAT-LINE-MAX
               PERFORM H100-PRINT-HEADING THRU H199-EXIT.

           SET CAT-IDX                            TO  1.
           SEARCH  CATEGORIES                     VARYING CAT-IDX
               AT END
                   MOVE "NO DESCRIPTION FOUND" TO PRT-CATEGORY-DESC
               WHEN CATEGORY (CAT-IDX) = OURSTUFF-CLASS
                   MOVE CAT-DESC (CAT-IDX) TO PRT-CATEGORY-DESC.

           IF  SUB-TOTAL-AMT GREATER THAN ZERO
               PERFORM T100-GIVE-SUB-TOTAL THRU T199-EXIT.

           WRITE PRINT-FILE-RECORD     FROM  HD-BLANK-LINE     AFTER 1.
           WRITE PRINT-FILE-RECORD     FROM  PRT-CATEGORY-DESC AFTER 1.
           WRITE PRINT-FILE-RECORD     FROM  HD-BLANK-LINE     AFTER 1.
           ADD  3                          TO  HD-LINE-CNT.

       H299-EXIT.

           EXIT.




       P100-PRINT-DETAIL.

           IF  HD-LINE-CNT NOT LESS THAN HD-LINE-MAX
               PERFORM H100-PRINT-HEADING THRU H199-EXIT.

           WRITE PRINT-FILE-RECORD     FROM  DETAIL-LINE-1 AFTER 1.

           ADD  1                          TO  HD-LINE-CNT.

       P199-EXIT.

           EXIT.




       R100-START.

           MOVE  SPACES                    TO  OURSTUFF-KEY.
           START MASTER-FILE       KEY IS NOT LESS THAN OURSTUFF-KEY
               INVALID KEY
                   PERFORM V100-FILE-IO-ERROR THRU V199-EXIT.

       R199-EXIT.

           EXIT.




       R200-READ-NEXT.

           READ MASTER-FILE
               NEXT RECORD.

           IF  FILE-STAT = "10"
               MOVE  "Y" TO END-INPUT-FLAG
               GO TO R299-EXIT.

           IF  FILE-STAT NOT = "00"
               PERFORM V100-FILE-IO-ERROR THRU V199-EXIT.

       R299-EXIT.

           EXIT.





       T100-GIVE-SUB-TOTAL.

           MOVE  SUB-TOTAL-AMT             TO  TL-AMOUNT.
           ADD   SUB-TOTAL-AMT             TO  GRAND-TOTAL-AMT.
           MOVE  ZERO                      TO  SUB-TOTAL-AMT.
           WRITE PRINT-FILE-RECORD         FROM  TOTAL-LINE     AFTER 1.
           ADD  1                          TO  HD-LINE-CNT.

       T199-EXIT.

           EXIT.




       T200-GIVE-GRAND-TOTAL.

           WRITE PRINT-FILE-RECORD         FROM  HD-BLANK-LINE  AFTER 1.
           MOVE  GRAND-TOTAL-AMT           TO  TL-AMOUNT.
           MOVE  "* GRAND TOTAL *"         TO  TL-TOT-WD.
           WRITE PRINT-FILE-RECORD         FROM  TOTAL-LINE     AFTER 1.
           ADD  2                          TO  HD-LINE-CNT.

       T299-EXIT.

           EXIT.




       V100-FILE-IO-ERROR.

           DISPLAY "FILE I/O ERROR ... FILE STATUS = " FILE-STAT.

       V199-EXIT.

           EXIT.


